==> wj_social_net_queries-0.2.1-py3-none-any.whl: wj_social_net_queries/utils/utils.py <==
import json
import logging
from datetime import datetime
from urllib.request import urlretrieve

import pandas as pd

from social_net_queries.wj_social_net_queries.utils.constants.constants import CSV, JSON


def log_api_execption(function_name:str, code_status:int, details:dict):
    json_formatted_str = json.dumps(details, indent=2)
    logging.error(
        function_name + '\nCode: ' + str(code_status) + '\n' + json_formatted_str
    )


def safe_data_in_file(path:str, data, file_type:str):
    if file_type == JSON:
        pass
    elif file_type == CSV:
        safe_data_on_csv(path=path, data=data)

#TODO decorator for exceptions
def safe_data_on_csv(path:str, data:list, columns:list):
    try:
        if len(data) == 0:
            logging.info("No info")
            return
        df = pd.DataFrame(data)
        print(df)
        df.to_csv(path, mode='a', sep='|', index=False)
        logging.info("saved")
    except Exception as e:
        logging.error("safe_dict_on_csv :: " + str(e))


def save_data_on_json(path:str, data):
    try:
        jsonFile = open(path, "r")
        tmp_data = json.loads(jsonFile)
        jsonFile.close()
        tmp_data.update(data)
        jsonFile = open(path, "w+")
        jsonFile.write(json.dumps(tmp_data))
        jsonFile.close()
    except:
        jsonFile = open(path, "w+")
        jsonFile.write(json.dumps(data))
        jsonFile.close()


def download_image(url, filename):
    try:
        urlretrieve(url, filename)
    except Exception as e:
        print(e)

#TODO: Mejorar esta función!
def get_file_extension(file_name):
    return file_name.split('.')[-1]


#TODO: Mejorar esta función!
def generate_file_name_with_datetime(extension:str):
    name = str(datetime.now())
    print("Datetime::", name)
    name = name.replace(" ","")
    name = name.replace("-","")
    name = name.replace(":","")
    name = name.replace(".","")
    return name + '.' + extension

==> wj_social_net_queries-0.2.2-py3-none-any.whl: wj_social_net_queries/utils/utils.py <==
import json
import logging
from datetime import datetime
from urllib.request import urlretrieve

import pandas as pd

from wj_social_net_queries.utils.constants.constants import CSV, JSON


def log_api_execption(function_name:str, code_status:int, details:dict):
    json_formatted_str = json.dumps(details, indent=2)
    logging.error(
        function_name + '\nCode: ' + str(code_status) + '\n' + json_formatted_str
    )


def safe_data_in_file(path:str, data, file_type:str):
    if file_type == JSON:
        pass
    elif file_type == CSV:
        safe_data_on_csv(path=path, data=data)

#TODO decorator for exceptions
def safe_data_on_csv(path:str, data:list, columns:list):
    try:
        if len(data) == 0:
            logging.info("No info")
            return
        df = pd.DataFrame(data)
        print(df)
        df.to_csv(path, mode='a', sep='|', index=False)
        logging.info("saved")
    except Exception as e:
        logging.error("safe_dict_on_csv :: " + str(e))


def save_data_on_json(path:str, data):
    try:
        jsonFile = open(path, "r")
        tmp_data = json.loads(jsonFile)
        jsonFile.close()
        tmp_data.update(data)
        jsonFile = open(path, "w+")
        jsonFile.write(json.dumps(tmp_data))
        jsonFile.close()
    except:
        jsonFile = open(path, "w+")
        jsonFile.write(json.dumps(data))
        jsonFile.close()


def download_image(url, filename):
    try:
        urlretrieve(url, filename)
    except Exception as e:
        print(e)

#TODO: Mejorar esta función!
def get_file_extension(file_name):
    return file_name.split('.')[-1]


#TODO: Mejorar esta función!
def generate_file_name_with_datetime(extension:str):
    name = str(datetime.now())
    print("Datetime::", name)
    name = name.replace(" ","")
    name = name.replace("-","")
    name = name.replace(":","")
    name = name.replace(".","")
    return name + '.' + extension
